@@ -83,13 +83,17 @@ static const lib1770_biquad_t *lib1770_f2_48000(void)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
+#if defined (LIB1770_LFE) // [
+lib1770_pre_t *lib1770_pre_new_lfe(double samplerate, int channels, int lfe)
+#else // ] [
 lib1770_pre_t *lib1770_pre_new(double samplerate, int channels)
+#endif // ]
 {
   lib1770_pre_t *pre;
-  int i;
+  int i,ch;
 
   pre=LIB1770_CALLOC(1,sizeof *pre);
-  LIB1770_GOTO(NULL==pre,"allocation bs.1770 pre-filter",pre);
+  LIB1770_GOTO(NULL==pre,"allocation bs.1770 pre-filter",epre);
 
   pre->block=NULL;
 
@@ -97,6 +101,15 @@ lib1770_pre_t *lib1770_pre_new(double samplerate, int channels)
   pre->samplerate=samplerate;
   // set the number of channals.
   pre->channels=channels;
+#if defined (LIB1770_LFE) // [
+  // set the lfe channal.
+  if (LIB1770_LFE<lfe) {
+    PBU_DVMESSAGE("lfe overflow: %d (%d)",lfe,LIB1770_LFE);
+    goto elfe;
+  }
+
+  pre->lfe=lfe;
+#endif // ]
 
   // requantize the f1-filter according to the sample frequency.
   pre->f1.samplerate=samplerate;
@@ -107,18 +120,36 @@ lib1770_pre_t *lib1770_pre_new(double samplerate, int channels)
   lib1770_biquad_requantize(&pre->f2,lib1770_f2_48000());
 
   // initialize the pre buffer.
-  for (i=0;i<LIB1770_MIN(channels,LIB1770_MAX_CHANNELS);++i)
-    LIB1770_GETX(pre->ring.buf[i],0,0)=0.0;
+  for (i=0,ch=0;i<LIB1770_MIN(channels,LIB1770_MAX_CHANNELS);++i) {
+#if defined (LIB1770_LFE) // [
+		// filter out the lfe channel.
+		if (i==lfe)
+			continue;
+#endif // ]
+
+    LIB1770_GETX(pre->ring.buf[ch],0,0)=0.0;
+		++ch;
+	}
 
   pre->ring.offs=1;
   pre->ring.size=pre->ring.offs;
 
   return pre;
   //LIB1770_FREE(pre);
-pre:
+epre:
+#if defined (LIB1770_LFE) // [
+elfe:
+#endif // ]
   return NULL;
 }
 
+#if defined (LIB1770_LFE) // [
+lib1770_pre_t *lib1770_pre_new(double samplerate, int channels)
+{
+  return lib1770_pre_new_lfe(samplerate,channels,-1);
+}
+#endif // ]
+
 void lib1770_pre_close(lib1770_pre_t *pre)
 {
   LIB1770_FREE(pre);
@@ -137,15 +168,26 @@ void lib1770_pre_add_sample(lib1770_pre_t *pre, lib1770_sample_t sample)
   double wssqs=0.0;
   double *g=lib1770_g;
   int channels=pre->channels;
+#if defined (LIB1770_LFE) // [
+  int lfe=pre->lfe;
+#endif // ]
   int offs=pre->ring.offs;
   int size=pre->ring.size;
-  int i;
+  int i,ch;
   lib1770_block_t *block;
   double den_tmp;
+  double *buf;
+  double x;
 
-  for (i=0;i<LIB1770_MIN(channels,LIB1770_MAX_CHANNELS);++i) {
-    double *buf=pre->ring.buf[i];
-    double x=LIB1770_GETX(buf,offs,0)=LIB1770_DEN(sample[i]);
+  for (i=0,ch=0;i<LIB1770_MIN(channels,LIB1770_MAX_CHANNELS);++i) {
+#if defined (LIB1770_LFE) // [
+		// filter out the lfe channel.
+		if (lfe==i)
+			continue;
+#endif // ]
+
+    buf=pre->ring.buf[ch];
+    x=LIB1770_GETX(buf,offs,0)=LIB1770_DEN(sample[ch]);
 
     if (1<size) {
       double y=LIB1770_GETY(buf,offs,0)=LIB1770_DEN(f1->b0*x
@@ -159,6 +201,8 @@ void lib1770_pre_add_sample(lib1770_pre_t *pre, lib1770_sample_t sample)
       wssqs+=(*g++)*z*z;
       ++buf;
     }
+
+		++ch;
   }
 
   for (block=pre->block;NULL!=block;block=block->next)
@@ -174,12 +218,23 @@ void lib1770_pre_add_sample(lib1770_pre_t *pre, lib1770_sample_t sample)
 void lib1770_pre_flush(lib1770_pre_t *pre)
 {
   int channels=pre->channels;
+#if defined (LIB1770_LFE) // [
+  int lfe=pre->lfe;
+#endif // ]
   lib1770_sample_t sample;
-  int i;
+  int i,ch;
 
   if (1<pre->ring.size) {
-    for (i=0;i<channels;++i)
-      sample[i]=0.0;
+  	for (i=0,ch=0;i<LIB1770_MIN(channels,LIB1770_MAX_CHANNELS);++i) {
+#if defined (LIB1770_LFE) // [
+			// filter out the lfe channel.
+			if (lfe==i)
+				continue;
+#endif // ]
+
+      sample[ch]=0.0;
+			++ch;
+		}
 
     lib1770_pre_add_sample(pre,sample);
   }
